@@ -2,6 +2,7 @@ from actionpack.actions.make_request import MakeRequest
 from actionpack.actions.read_bytes import ReadBytes
 from actionpack.actions.read_input import ReadInput
 from actionpack.actions.retry_policy import RetryPolicy
+from actionpack.actions.serialization import Serialization
 from actionpack.actions.write_bytes import WriteBytes
 
 
@@ -10,6 +11,7 @@ __all__ = [
     'ReadBytes',
     'ReadInput',
     'RetryPolicy',
+    'Serialization',
     'WriteBytes'
 ]
 
