@@ -62,10 +62,11 @@ class KeyedProcedure(Procedure):
                 msg = f'All {self.__class__.__name__} Actions must have a name: {str(action)}'
                 raise KeyedProcedure.UnnamedAction(msg)
 
-    def execute(self, max_workers: int=5):
+    def execute(self, max_workers: int=5, should_raise: bool=False):
         if self.sync:
             for action in self.actions:
-                yield action.name, action.perform()
+                yield (action.name, action.perform(should_raise=should_raise)) \
+                      if should_raise else (action.name, action.perform())
         else:
             with ThreadPoolExecutor(max_workers=max_workers) as executor:
                 futures = {executor.submit(action.perform): action for action in self}
